OC.L10N.register(
    "templateeditor",
    {
    "Could not load template" : "Šablonu nelze nahrát",
    "Saved" : "Uloženo",
    "Reset" : "Reset",
    "An error occurred" : "Nastala chyba",
    "Sharing email - public link shares (HTML)" : "Email o sdílení - sdíleno veřejným odkazem (HTML)",
    "Sharing email - public link shares (plain text fallback)" : "Email o sdílení - sdíleno veřejným odkazem (čistý text)",
    "Sharing email (HTML)" : "Sdílet email (HTML)",
    "Sharing email (plain text fallback)" : "Sdílet email (pouze prostý text)",
    "Lost password mail" : "Email se zapomenutým heslem",
    "New user email (HTML)" : "Email novému uživateli (HTML)",
    "New user email (plain text fallback)" : "Email novému uživateli (čistý text)",
    "Activity notification mail" : "Emailová upozornění na aktivitu",
    "Mail Templates" : "Šablony emailů",
    "Theme" : "Vzhled",
    "Template" : "Šablona",
    "Please choose a template" : "Zvolte prosím šablonu",
    "Save" : "Uložit"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
